/****************************************************************************
** Meta object code from reading C++ file 'frequentlyusedproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../frequentlyusedproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'frequentlyusedproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24FrequentlyUsedProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FrequentlyUsedProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN24FrequentlyUsedProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FrequentlyUsedProxyModel",
        "QML.Element",
        "recentlyInstalledModelChanged",
        "",
        "desktopIdRoleChanged",
        "launchedTimesRoleChanged",
        "lastLaunchedTimeRoleChanged",
        "recentlyInstalledModel",
        "QAbstractItemModel*",
        "desktopIdRole",
        "launchedTimesRole",
        "lastLaunchedTimeRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'recentlyInstalledModelChanged'
        QtMocHelpers::SignalData<void()>(2, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopIdRoleChanged'
        QtMocHelpers::SignalData<void(int)>(4, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'launchedTimesRoleChanged'
        QtMocHelpers::SignalData<void(int)>(5, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'lastLaunchedTimeRoleChanged'
        QtMocHelpers::SignalData<void(int)>(6, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'recentlyInstalledModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'desktopIdRole'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'launchedTimesRole'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'lastLaunchedTimeRole'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
    });
    return QtMocHelpers::metaObjectData<FrequentlyUsedProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FrequentlyUsedProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24FrequentlyUsedProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24FrequentlyUsedProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24FrequentlyUsedProxyModelE_t>.metaTypes,
    nullptr
} };

void FrequentlyUsedProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FrequentlyUsedProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->recentlyInstalledModelChanged(); break;
        case 1: _t->desktopIdRoleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->launchedTimesRoleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->lastLaunchedTimeRoleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FrequentlyUsedProxyModel::*)()>(_a, &FrequentlyUsedProxyModel::recentlyInstalledModelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrequentlyUsedProxyModel::*)(int )>(_a, &FrequentlyUsedProxyModel::desktopIdRoleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrequentlyUsedProxyModel::*)(int )>(_a, &FrequentlyUsedProxyModel::launchedTimesRoleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrequentlyUsedProxyModel::*)(int )>(_a, &FrequentlyUsedProxyModel::lastLaunchedTimeRoleChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->recentlyInstalledModel(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->m_desktopIdRole; break;
        case 2: *reinterpret_cast<int*>(_v) = _t->m_launchedTimesRole; break;
        case 3: *reinterpret_cast<int*>(_v) = _t->m_lastLaunchedTimeRole; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRecentlyInstalledModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_desktopIdRole, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->desktopIdRoleChanged(_t->m_desktopIdRole);
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_launchedTimesRole, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->launchedTimesRoleChanged(_t->m_launchedTimesRole);
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_lastLaunchedTimeRole, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->lastLaunchedTimeRoleChanged(_t->m_lastLaunchedTimeRole);
            break;
        default: break;
        }
    }
}

const QMetaObject *FrequentlyUsedProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FrequentlyUsedProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24FrequentlyUsedProxyModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int FrequentlyUsedProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void FrequentlyUsedProxyModel::recentlyInstalledModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FrequentlyUsedProxyModel::desktopIdRoleChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FrequentlyUsedProxyModel::launchedTimesRoleChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FrequentlyUsedProxyModel::lastLaunchedTimeRoleChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
