/****************************************************************************
** Meta object code from reading C++ file 'launchercontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../launchercontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'launchercontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18LauncherControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto LauncherController::qt_create_metaobjectdata<qt_meta_tag_ZN18LauncherControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LauncherController",
        "QML.Element",
        "QML.Singleton",
        "true",
        "currentFrameChanged",
        "",
        "currentScreenChanged",
        "visibleChanged",
        "visible",
        "Closed",
        "Shown",
        "VisibleChanged",
        "hideWithTimer",
        "setAvoidHide",
        "avoidHide",
        "cancelHide",
        "adjustFontWeight",
        "QFont",
        "f",
        "QFont::Weight",
        "weight",
        "closeAllPopups",
        "showHelp",
        "setCurrentFrameToWindowedFrame",
        "currentFrame",
        "currentScreen",
        "Visible"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentFrameChanged'
        QtMocHelpers::SignalData<void()>(4, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentScreenChanged'
        QtMocHelpers::SignalData<void()>(6, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'Closed'
        QtMocHelpers::SignalData<void()>(9, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Shown'
        QtMocHelpers::SignalData<void()>(10, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'VisibleChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Method 'hideWithTimer'
        QtMocHelpers::MethodData<void()>(12, 5, QMC::AccessPublic, QMetaType::Void),
        // Method 'setAvoidHide'
        QtMocHelpers::MethodData<void(bool)>(13, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Method 'cancelHide'
        QtMocHelpers::MethodData<void()>(15, 5, QMC::AccessPublic, QMetaType::Void),
        // Method 'adjustFontWeight'
        QtMocHelpers::MethodData<QFont(const QFont &, QFont::Weight)>(16, 5, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Method 'closeAllPopups'
        QtMocHelpers::MethodData<void()>(21, 5, QMC::AccessPublic, QMetaType::Void),
        // Method 'showHelp'
        QtMocHelpers::MethodData<void()>(22, 5, QMC::AccessPublic, QMetaType::Void),
        // Method 'setCurrentFrameToWindowedFrame'
        QtMocHelpers::MethodData<void()>(23, 5, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'currentFrame'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'currentScreen'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'Visible'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
    });
    return QtMocHelpers::metaObjectData<LauncherController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject LauncherController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18LauncherControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18LauncherControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18LauncherControllerE_t>.metaTypes,
    nullptr
} };

void LauncherController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LauncherController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentFrameChanged(); break;
        case 1: _t->currentScreenChanged(); break;
        case 2: _t->visibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->Closed(); break;
        case 4: _t->Shown(); break;
        case 5: _t->VisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->hideWithTimer(); break;
        case 7: _t->setAvoidHide((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->cancelHide(); break;
        case 9: { QFont _r = _t->adjustFontWeight((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFont::Weight>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QFont*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->closeAllPopups(); break;
        case 11: _t->showHelp(); break;
        case 12: _t->setCurrentFrameToWindowedFrame(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LauncherController::*)()>(_a, &LauncherController::currentFrameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LauncherController::*)()>(_a, &LauncherController::currentScreenChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LauncherController::*)(bool )>(_a, &LauncherController::visibleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LauncherController::*)()>(_a, &LauncherController::Closed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LauncherController::*)()>(_a, &LauncherController::Shown, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LauncherController::*)(bool )>(_a, &LauncherController::VisibleChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->visible(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->currentFrame(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->currentScreen(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->visible(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisible(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setCurrentFrame(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setCurrentScreen(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LauncherController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LauncherController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18LauncherControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LauncherController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void LauncherController::currentFrameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LauncherController::currentScreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LauncherController::visibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void LauncherController::Closed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LauncherController::Shown()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LauncherController::VisibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
