/****************************************************************************
** Meta object code from reading C++ file 'appitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../appitem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7AppItemE_t {};
} // unnamed namespace

template <> constexpr inline auto AppItem::qt_create_metaobjectdata<qt_meta_tag_ZN7AppItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AppItem",
        "QML.Element",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "AppItem should only be created from C++ side",
        "Roles",
        "DesktopIdRole",
        "Categories",
        "DDECategoryRole",
        "IconNameRole",
        "NameRole",
        "InstalledTimeRole",
        "LastLaunchedTimeRole",
        "LaunchedTimesRole",
        "IsAutoStartRole",
        "VendorRole",
        "GenericNameRole",
        "ModelExtendedRole",
        "DDECategories",
        "Internet",
        "Chat",
        "Music",
        "Video",
        "Graphics",
        "Game",
        "Office",
        "Reading",
        "Development",
        "System",
        "Others"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(6, 6, QMC::EnumFlags{}).add({
            {    7, Roles::DesktopIdRole },
            {    8, Roles::Categories },
            {    9, Roles::DDECategoryRole },
            {   10, Roles::IconNameRole },
            {   11, Roles::NameRole },
            {   12, Roles::InstalledTimeRole },
            {   13, Roles::LastLaunchedTimeRole },
            {   14, Roles::LaunchedTimesRole },
            {   15, Roles::IsAutoStartRole },
            {   16, Roles::VendorRole },
            {   17, Roles::GenericNameRole },
            {   18, Roles::ModelExtendedRole },
        }),
        // enum 'DDECategories'
        QtMocHelpers::EnumData<enum DDECategories>(19, 19, QMC::EnumFlags{}).add({
            {   20, DDECategories::Internet },
            {   21, DDECategories::Chat },
            {   22, DDECategories::Music },
            {   23, DDECategories::Video },
            {   24, DDECategories::Graphics },
            {   25, DDECategories::Game },
            {   26, DDECategories::Office },
            {   27, DDECategories::Reading },
            {   28, DDECategories::Development },
            {   29, DDECategories::System },
            {   30, DDECategories::Others },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
            {    4,    5 },
    });
    return QtMocHelpers::metaObjectData<AppItem, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AppItem::staticMetaObject = { {
    QtPrivate::MetaObjectForType<QStandardItem>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7AppItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7AppItemE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7AppItemE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
