/****************************************************************************
** Meta object code from reading C++ file 'AppManager1Application.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "AppManager1Application.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AppManager1Application.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24__AppManager1ApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto __AppManager1Application::qt_create_metaobjectdata<qt_meta_tag_ZN24__AppManager1ApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__AppManager1Application",
        "ActionNameChanged",
        "",
        "PropMap",
        "value",
        "ActionsChanged",
        "AutoStartChanged",
        "CategoriesChanged",
        "EnvironChanged",
        "GenericNameChanged",
        "QStringMap",
        "IDChanged",
        "IconsChanged",
        "InstalledTimeChanged",
        "InstancesChanged",
        "QList<QDBusObjectPath>",
        "LastLaunchedTimeChanged",
        "LaunchedTimesChanged",
        "MimeTypesChanged",
        "NameChanged",
        "NoDisplayChanged",
        "TerminalChanged",
        "X_Deepin_VendorChanged",
        "X_FlatpakChanged",
        "X_linglongChanged",
        "IsOnDesktopChanged",
        "Launch",
        "QDBusPendingReply<QDBusObjectPath>",
        "action",
        "fields",
        "QVariantMap",
        "options",
        "RemoveFromDesktop",
        "QDBusPendingReply<bool>",
        "SendToDesktop",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "ActionName",
        "Actions",
        "AutoStart",
        "Categories",
        "Environ",
        "GenericName",
        "ID",
        "Icons",
        "InstalledTime",
        "Instances",
        "LastLaunchedTime",
        "LaunchedTimes",
        "MimeTypes",
        "Name",
        "NoDisplay",
        "Terminal",
        "X_Deepin_Vendor",
        "X_Flatpak",
        "X_linglong",
        "isOnDesktop"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActionNameChanged'
        QtMocHelpers::SignalData<void(PropMap) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'ActionsChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'AutoStartChanged'
        QtMocHelpers::SignalData<void(bool) const>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'CategoriesChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'EnvironChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'GenericNameChanged'
        QtMocHelpers::SignalData<void(const QStringMap &) const>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Signal 'IDChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'IconsChanged'
        QtMocHelpers::SignalData<void(const QStringMap &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Signal 'InstalledTimeChanged'
        QtMocHelpers::SignalData<void(qlonglong) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 4 },
        }}),
        // Signal 'InstancesChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 4 },
        }}),
        // Signal 'LastLaunchedTimeChanged'
        QtMocHelpers::SignalData<void(qlonglong) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 4 },
        }}),
        // Signal 'LaunchedTimesChanged'
        QtMocHelpers::SignalData<void(qlonglong) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 4 },
        }}),
        // Signal 'MimeTypesChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'NameChanged'
        QtMocHelpers::SignalData<void(const QStringMap &) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Signal 'NoDisplayChanged'
        QtMocHelpers::SignalData<void(bool) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'TerminalChanged'
        QtMocHelpers::SignalData<void(bool) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'X_Deepin_VendorChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'X_FlatpakChanged'
        QtMocHelpers::SignalData<void(bool) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'X_linglongChanged'
        QtMocHelpers::SignalData<void(bool) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'IsOnDesktopChanged'
        QtMocHelpers::SignalData<void(bool) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'Launch'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QStringList &, const QVariantMap &)>(26, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 28 }, { QMetaType::QStringList, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'RemoveFromDesktop'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(32, 2, QMC::AccessPublic, 0x80000000 | 33),
        // Slot 'SendToDesktop'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(34, 2, QMC::AccessPublic, 0x80000000 | 33),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 36 }, { 0x80000000 | 37, 38 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 43 }, { 0x80000000 | 44, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ActionName'
        QtMocHelpers::PropertyData<PropMap>(45, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'Actions'
        QtMocHelpers::PropertyData<QStringList>(46, QMetaType::QStringList, QMC::DefaultPropertyFlags, 1),
        // property 'AutoStart'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'Categories'
        QtMocHelpers::PropertyData<QStringList>(48, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'Environ'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'GenericName'
        QtMocHelpers::PropertyData<QStringMap>(50, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'ID'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'Icons'
        QtMocHelpers::PropertyData<QStringMap>(52, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'InstalledTime'
        QtMocHelpers::PropertyData<qlonglong>(53, QMetaType::LongLong, QMC::DefaultPropertyFlags, 8),
        // property 'Instances'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(54, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'LastLaunchedTime'
        QtMocHelpers::PropertyData<qlonglong>(55, QMetaType::LongLong, QMC::DefaultPropertyFlags, 10),
        // property 'LaunchedTimes'
        QtMocHelpers::PropertyData<qlonglong>(56, QMetaType::LongLong, QMC::DefaultPropertyFlags, 11),
        // property 'MimeTypes'
        QtMocHelpers::PropertyData<QStringList>(57, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'Name'
        QtMocHelpers::PropertyData<QStringMap>(58, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
        // property 'NoDisplay'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'Terminal'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags, 15),
        // property 'X_Deepin_Vendor'
        QtMocHelpers::PropertyData<QString>(61, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
        // property 'X_Flatpak'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags, 17),
        // property 'X_linglong'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags, 18),
        // property 'isOnDesktop'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags, 19),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__AppManager1Application, qt_meta_tag_ZN24__AppManager1ApplicationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __AppManager1Application::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24__AppManager1ApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24__AppManager1ApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24__AppManager1ApplicationE_t>.metaTypes,
    nullptr
} };

void __AppManager1Application::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__AppManager1Application *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActionNameChanged((*reinterpret_cast<std::add_pointer_t<PropMap>>(_a[1]))); break;
        case 1: _t->ActionsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->AutoStartChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->CategoriesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->EnvironChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->GenericNameChanged((*reinterpret_cast<std::add_pointer_t<QStringMap>>(_a[1]))); break;
        case 6: _t->IDChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->IconsChanged((*reinterpret_cast<std::add_pointer_t<QStringMap>>(_a[1]))); break;
        case 8: _t->InstalledTimeChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 9: _t->InstancesChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 10: _t->LastLaunchedTimeChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 11: _t->LaunchedTimesChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 12: _t->MimeTypesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 13: _t->NameChanged((*reinterpret_cast<std::add_pointer_t<QStringMap>>(_a[1]))); break;
        case 14: _t->NoDisplayChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->TerminalChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->X_Deepin_VendorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->X_FlatpakChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->X_linglongChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->IsOnDesktopChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: { QDBusPendingReply<QDBusObjectPath> _r = _t->Launch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<bool> _r = _t->RemoveFromDesktop();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<bool> _r = _t->SendToDesktop();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 24: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 25: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PropMap >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QStringMap >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QStringMap >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QStringMap >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(PropMap ) const>(_a, &__AppManager1Application::ActionNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QStringList & ) const>(_a, &__AppManager1Application::ActionsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(bool ) const>(_a, &__AppManager1Application::AutoStartChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QStringList & ) const>(_a, &__AppManager1Application::CategoriesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QString & ) const>(_a, &__AppManager1Application::EnvironChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QStringMap & ) const>(_a, &__AppManager1Application::GenericNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QString & ) const>(_a, &__AppManager1Application::IDChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QStringMap & ) const>(_a, &__AppManager1Application::IconsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(qlonglong ) const>(_a, &__AppManager1Application::InstalledTimeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QList<QDBusObjectPath> & ) const>(_a, &__AppManager1Application::InstancesChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(qlonglong ) const>(_a, &__AppManager1Application::LastLaunchedTimeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(qlonglong ) const>(_a, &__AppManager1Application::LaunchedTimesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QStringList & ) const>(_a, &__AppManager1Application::MimeTypesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QStringMap & ) const>(_a, &__AppManager1Application::NameChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(bool ) const>(_a, &__AppManager1Application::NoDisplayChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(bool ) const>(_a, &__AppManager1Application::TerminalChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(const QString & ) const>(_a, &__AppManager1Application::X_Deepin_VendorChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(bool ) const>(_a, &__AppManager1Application::X_FlatpakChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(bool ) const>(_a, &__AppManager1Application::X_linglongChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (__AppManager1Application::*)(bool ) const>(_a, &__AppManager1Application::IsOnDesktopChanged, 19))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PropMap >(); break;
        case 13:
        case 7:
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QStringMap >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<PropMap*>(_v) = _t->actionName(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->actions(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->autoStart(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->categories(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->environ(); break;
        case 5: *reinterpret_cast<QStringMap*>(_v) = _t->genericName(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->iD(); break;
        case 7: *reinterpret_cast<QStringMap*>(_v) = _t->icons(); break;
        case 8: *reinterpret_cast<qlonglong*>(_v) = _t->installedTime(); break;
        case 9: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->instances(); break;
        case 10: *reinterpret_cast<qlonglong*>(_v) = _t->lastLaunchedTime(); break;
        case 11: *reinterpret_cast<qlonglong*>(_v) = _t->launchedTimes(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->mimeTypes(); break;
        case 13: *reinterpret_cast<QStringMap*>(_v) = _t->name(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->noDisplay(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->terminal(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->x_Deepin_Vendor(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->x_Flatpak(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->x_linglong(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isOnDesktop(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setAutoStart(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setEnviron(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setMimeTypes(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *__AppManager1Application::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__AppManager1Application::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24__AppManager1ApplicationE_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __AppManager1Application::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void __AppManager1Application::ActionNameChanged(PropMap _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void __AppManager1Application::ActionsChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void __AppManager1Application::AutoStartChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __AppManager1Application::CategoriesChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void __AppManager1Application::EnvironChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void __AppManager1Application::GenericNameChanged(const QStringMap & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __AppManager1Application::IDChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __AppManager1Application::IconsChanged(const QStringMap & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __AppManager1Application::InstalledTimeChanged(qlonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __AppManager1Application::InstancesChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __AppManager1Application::LastLaunchedTimeChanged(qlonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __AppManager1Application::LaunchedTimesChanged(qlonglong _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __AppManager1Application::MimeTypesChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __AppManager1Application::NameChanged(const QStringMap & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __AppManager1Application::NoDisplayChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void __AppManager1Application::TerminalChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void __AppManager1Application::X_Deepin_VendorChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void __AppManager1Application::X_FlatpakChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void __AppManager1Application::X_linglongChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void __AppManager1Application::IsOnDesktopChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< __AppManager1Application *>(this), &staticMetaObject, 19, nullptr, _t1);
}
QT_WARNING_POP
