/****************************************************************************
** Meta object code from reading C++ file 'itemarrangementproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../itemarrangementproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemarrangementproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25ItemArrangementProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemArrangementProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN25ItemArrangementProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemArrangementProxyModel",
        "QML.Element",
        "QML.Singleton",
        "true",
        "topLevelPageCountChanged",
        "",
        "folderPageCountChanged",
        "folderId",
        "itemBroughtToFront",
        "pageCount",
        "updateFolderName",
        "name",
        "bringToFront",
        "id",
        "commitDndOperation",
        "dragId",
        "dropId",
        "DndOperation",
        "op",
        "pageHint",
        "creatEmptyPage",
        "removeEmptyPage",
        "ItemType",
        "AppItemType",
        "FolderItemType",
        "Roles",
        "PageRole",
        "IndexInPageRole",
        "FolderIdNumberRole",
        "IconsNameRole",
        "ItemTypeRole",
        "DndPrepend",
        "DndJoin",
        "DndAppend"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'topLevelPageCountChanged'
        QtMocHelpers::SignalData<void()>(4, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'folderPageCountChanged'
        QtMocHelpers::SignalData<void(int)>(6, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'itemBroughtToFront'
        QtMocHelpers::SignalData<void()>(8, 5, QMC::AccessPublic, QMetaType::Void),
        // Method 'pageCount'
        QtMocHelpers::MethodData<int(int) const>(9, 5, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'pageCount'
        QtMocHelpers::MethodData<int() const>(9, 5, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'updateFolderName'
        QtMocHelpers::MethodData<void(int, const QString &)>(10, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 11 },
        }}),
        // Method 'bringToFront'
        QtMocHelpers::MethodData<void(const QString &)>(12, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'commitDndOperation'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const DndOperation, int)>(14, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 },
        }}),
        // Method 'commitDndOperation'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const DndOperation)>(14, 5, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Method 'creatEmptyPage'
        QtMocHelpers::MethodData<int(int) const>(20, 5, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'creatEmptyPage'
        QtMocHelpers::MethodData<int() const>(20, 5, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'removeEmptyPage'
        QtMocHelpers::MethodData<void() const>(21, 5, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ItemType'
        QtMocHelpers::EnumData<enum ItemType>(22, 22, QMC::EnumFlags{}).add({
            {   23, ItemType::AppItemType },
            {   24, ItemType::FolderItemType },
        }),
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(25, 25, QMC::EnumFlags{}).add({
            {   26, Roles::PageRole },
            {   27, Roles::IndexInPageRole },
            {   28, Roles::FolderIdNumberRole },
            {   29, Roles::IconsNameRole },
            {   30, Roles::ItemTypeRole },
        }),
        // enum 'DndOperation'
        QtMocHelpers::EnumData<enum DndOperation>(17, 17, QMC::EnumFlags{}).add({
            {   31, DndOperation::DndPrepend },
            {   32, DndOperation::DndJoin },
            {   33, DndOperation::DndAppend },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
    });
    return QtMocHelpers::metaObjectData<ItemArrangementProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ItemArrangementProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QConcatenateTablesProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ItemArrangementProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ItemArrangementProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25ItemArrangementProxyModelE_t>.metaTypes,
    nullptr
} };

void ItemArrangementProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemArrangementProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->topLevelPageCountChanged(); break;
        case 1: _t->folderPageCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->itemBroughtToFront(); break;
        case 3: { int _r = _t->pageCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->pageCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->updateFolderName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->bringToFront((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->commitDndOperation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<enum DndOperation>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 8: _t->commitDndOperation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<enum DndOperation>>(_a[3]))); break;
        case 9: { int _r = _t->creatEmptyPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->creatEmptyPage();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->removeEmptyPage(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItemArrangementProxyModel::*)()>(_a, &ItemArrangementProxyModel::topLevelPageCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemArrangementProxyModel::*)(int )>(_a, &ItemArrangementProxyModel::folderPageCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemArrangementProxyModel::*)()>(_a, &ItemArrangementProxyModel::itemBroughtToFront, 2))
            return;
    }
}

const QMetaObject *ItemArrangementProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemArrangementProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ItemArrangementProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QConcatenateTablesProxyModel::qt_metacast(_clname);
}

int ItemArrangementProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QConcatenateTablesProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ItemArrangementProxyModel::topLevelPageCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ItemArrangementProxyModel::folderPageCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ItemArrangementProxyModel::itemBroughtToFront()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
