/****************************************************************************
** Meta object code from reading C++ file 'desktopintegration.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../desktopintegration.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'desktopintegration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18DesktopIntegrationE_t {};
} // unnamed namespace

template <> constexpr inline auto DesktopIntegration::qt_create_metaobjectdata<qt_meta_tag_ZN18DesktopIntegrationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DesktopIntegration",
        "QML.Element",
        "QML.Singleton",
        "true",
        "dockPositionChanged",
        "",
        "dockGeometryChanged",
        "dockSpacingChanged",
        "backgroundUrlChanged",
        "opacityChanged",
        "scaleFactorChanged",
        "iconScaleFactorChanged",
        "currentDE",
        "isTreeLand",
        "openSystemSettings",
        "launchByDesktopId",
        "desktopId",
        "environmentVariable",
        "env",
        "disableScale",
        "setDisableScale",
        "showFolder",
        "QStandardPaths::StandardLocation",
        "location",
        "showUrl",
        "url",
        "appIsCompulsoryForDesktop",
        "appIsDummyPackage",
        "isDockedApp",
        "sendToDock",
        "removeFromDock",
        "isOnDesktop",
        "sendToDesktop",
        "removeFromDesktop",
        "isAutoStart",
        "setAutoStart",
        "on",
        "shouldSkipConfirmUninstallDialog",
        "uninstallApp",
        "scaleFactor",
        "dockPosition",
        "Qt::ArrowType",
        "dockGeometry",
        "QRect",
        "dockSpacing",
        "backgroundUrl",
        "opacity",
        "iconScaleFactor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dockPositionChanged'
        QtMocHelpers::SignalData<void()>(4, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dockGeometryChanged'
        QtMocHelpers::SignalData<void()>(6, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dockSpacingChanged'
        QtMocHelpers::SignalData<void()>(7, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundUrlChanged'
        QtMocHelpers::SignalData<void()>(8, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void()>(9, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleFactorChanged'
        QtMocHelpers::SignalData<void()>(10, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconScaleFactorChanged'
        QtMocHelpers::SignalData<void()>(11, 5, QMC::AccessPublic, QMetaType::Void),
        // Method 'currentDE'
        QtMocHelpers::MethodData<QString()>(12, 5, QMC::AccessPublic, QMetaType::QString),
        // Method 'isTreeLand'
        QtMocHelpers::MethodData<bool()>(13, 5, QMC::AccessPublic, QMetaType::Bool),
        // Method 'openSystemSettings'
        QtMocHelpers::MethodData<void()>(14, 5, QMC::AccessPublic, QMetaType::Void),
        // Method 'launchByDesktopId'
        QtMocHelpers::MethodData<void(const QString &)>(15, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'environmentVariable'
        QtMocHelpers::MethodData<QString(const QString &)>(17, 5, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'disableScale'
        QtMocHelpers::MethodData<double(const QString &)>(19, 5, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'setDisableScale'
        QtMocHelpers::MethodData<void(const QString &, double)>(20, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::Double, 19 },
        }}),
        // Method 'showFolder'
        QtMocHelpers::MethodData<void(QStandardPaths::StandardLocation)>(21, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Method 'showUrl'
        QtMocHelpers::MethodData<void(const QString &)>(24, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Method 'appIsCompulsoryForDesktop'
        QtMocHelpers::MethodData<bool(const QString &)>(26, 5, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'appIsDummyPackage'
        QtMocHelpers::MethodData<bool(const QString &)>(27, 5, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'isDockedApp'
        QtMocHelpers::MethodData<bool(const QString &) const>(28, 5, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'sendToDock'
        QtMocHelpers::MethodData<void(const QString &)>(29, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'removeFromDock'
        QtMocHelpers::MethodData<void(const QString &)>(30, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'isOnDesktop'
        QtMocHelpers::MethodData<bool(const QString &) const>(31, 5, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'sendToDesktop'
        QtMocHelpers::MethodData<void(const QString &)>(32, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'removeFromDesktop'
        QtMocHelpers::MethodData<void(const QString &)>(33, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'isAutoStart'
        QtMocHelpers::MethodData<bool(const QString &) const>(34, 5, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'setAutoStart'
        QtMocHelpers::MethodData<void(const QString &, bool)>(35, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::Bool, 36 },
        }}),
        // Method 'setAutoStart'
        QtMocHelpers::MethodData<void(const QString &)>(35, 5, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'shouldSkipConfirmUninstallDialog'
        QtMocHelpers::MethodData<bool(const QString &) const>(37, 5, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'uninstallApp'
        QtMocHelpers::MethodData<void(const QString &)>(38, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'scaleFactor'
        QtMocHelpers::MethodData<double() const>(39, 5, QMC::AccessPublic, QMetaType::Double),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dockPosition'
        QtMocHelpers::PropertyData<Qt::ArrowType>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'dockGeometry'
        QtMocHelpers::PropertyData<QRect>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'dockSpacing'
        QtMocHelpers::PropertyData<uint>(44, QMetaType::UInt, QMC::DefaultPropertyFlags, 2),
        // property 'backgroundUrl'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'opacity'
        QtMocHelpers::PropertyData<qreal>(46, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'scaleFactor'
        QtMocHelpers::PropertyData<double>(39, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'iconScaleFactor'
        QtMocHelpers::PropertyData<qreal>(47, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
    });
    return QtMocHelpers::metaObjectData<DesktopIntegration, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DesktopIntegration::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DesktopIntegrationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DesktopIntegrationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18DesktopIntegrationE_t>.metaTypes,
    nullptr
} };

void DesktopIntegration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DesktopIntegration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dockPositionChanged(); break;
        case 1: _t->dockGeometryChanged(); break;
        case 2: _t->dockSpacingChanged(); break;
        case 3: _t->backgroundUrlChanged(); break;
        case 4: _t->opacityChanged(); break;
        case 5: _t->scaleFactorChanged(); break;
        case 6: _t->iconScaleFactorChanged(); break;
        case 7: { QString _r = _t->currentDE();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->isTreeLand();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->openSystemSettings(); break;
        case 10: _t->launchByDesktopId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { QString _r = _t->environmentVariable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { double _r = _t->disableScale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setDisableScale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 14: _t->showFolder((*reinterpret_cast<std::add_pointer_t<QStandardPaths::StandardLocation>>(_a[1]))); break;
        case 15: _t->showUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: { bool _r = _t->appIsCompulsoryForDesktop((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->appIsDummyPackage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->isDockedApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->sendToDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->removeFromDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: { bool _r = _t->isOnDesktop((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->sendToDesktop((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->removeFromDesktop((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: { bool _r = _t->isAutoStart((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->setAutoStart((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 26: _t->setAutoStart((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: { bool _r = _t->shouldSkipConfirmUninstallDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->uninstallApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: { double _r = _t->scaleFactor();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DesktopIntegration::*)()>(_a, &DesktopIntegration::dockPositionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopIntegration::*)()>(_a, &DesktopIntegration::dockGeometryChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopIntegration::*)()>(_a, &DesktopIntegration::dockSpacingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopIntegration::*)()>(_a, &DesktopIntegration::backgroundUrlChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopIntegration::*)()>(_a, &DesktopIntegration::opacityChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopIntegration::*)()>(_a, &DesktopIntegration::scaleFactorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopIntegration::*)()>(_a, &DesktopIntegration::iconScaleFactorChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Qt::ArrowType*>(_v) = _t->dockPosition(); break;
        case 1: *reinterpret_cast<QRect*>(_v) = _t->dockGeometry(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->dockSpacing(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->backgroundUrl(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->opacity(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->scaleFactor(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->iconScaleFactor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setIconScaleFactor(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DesktopIntegration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DesktopIntegration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DesktopIntegrationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DesktopIntegration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DesktopIntegration::dockPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DesktopIntegration::dockGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DesktopIntegration::dockSpacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DesktopIntegration::backgroundUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DesktopIntegration::opacityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DesktopIntegration::scaleFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DesktopIntegration::iconScaleFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
