/****************************************************************************
** Meta object code from reading C++ file 'DaemonDock1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "DaemonDock1.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DaemonDock1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7__Dock1E_t {};
} // unnamed namespace

template <> constexpr inline auto __Dock1::qt_create_metaobjectdata<qt_meta_tag_ZN7__Dock1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "__Dock1",
        "DockAppSettingsSynced",
        "",
        "EntryAdded",
        "QDBusObjectPath",
        "in0",
        "in1",
        "EntryRemoved",
        "PluginSettingsSynced",
        "ServiceRestarted",
        "DisplayModeChanged",
        "value",
        "DockedAppsChanged",
        "EntriesChanged",
        "QList<QDBusObjectPath>",
        "FrontendWindowRectChanged",
        "QRect",
        "HideModeChanged",
        "HideStateChanged",
        "HideTimeoutChanged",
        "IconSizeChanged",
        "OpacityChanged",
        "PositionChanged",
        "ShowTimeoutChanged",
        "WindowMarginChanged",
        "WindowSizeChanged",
        "WindowSizeEfficientChanged",
        "WindowSizeFashionChanged",
        "ActivateWindow",
        "QDBusPendingReply<>",
        "ActivateWindowQueued",
        "CancelPreviewWindow",
        "CancelPreviewWindowQueued",
        "CloseWindow",
        "CloseWindowQueued",
        "GetDockedAppsDesktopFiles",
        "QDBusPendingReply<QStringList>",
        "GetEntryIDs",
        "GetPluginSettings",
        "QDBusPendingReply<QString>",
        "IsDocked",
        "QDBusPendingReply<bool>",
        "IsOnDock",
        "MakeWindowAbove",
        "MakeWindowAboveQueued",
        "MaximizeWindow",
        "MaximizeWindowQueued",
        "MergePluginSettings",
        "MergePluginSettingsQueued",
        "MinimizeWindow",
        "MinimizeWindowQueued",
        "MoveEntry",
        "MoveEntryQueued",
        "MoveWindow",
        "MoveWindowQueued",
        "PreviewWindow",
        "PreviewWindowQueued",
        "QueryWindowIdentifyMethod",
        "RemovePluginSettings",
        "RemovePluginSettingsQueued",
        "RequestDock",
        "RequestUndock",
        "SetFrontendWindowRect",
        "in2",
        "in3",
        "SetFrontendWindowRectQueued",
        "SetPluginSettings",
        "SetPluginSettingsQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "onPendingCallFinished",
        "QDBusPendingCallWatcher*",
        "w",
        "onPropertyChanged",
        "propName",
        "QVariant",
        "DisplayMode",
        "DockedApps",
        "Entries",
        "FrontendWindowRect",
        "HideMode",
        "HideState",
        "HideTimeout",
        "IconSize",
        "Opacity",
        "Position",
        "ShowTimeout",
        "WindowMargin",
        "WindowSize",
        "WindowSizeEfficient",
        "WindowSizeFashion"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'DockAppSettingsSynced'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EntryAdded'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'EntryRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'PluginSettingsSynced'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ServiceRestarted'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayModeChanged'
        QtMocHelpers::SignalData<void(int) const>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'DockedAppsChanged'
        QtMocHelpers::SignalData<void(const QStringList &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 11 },
        }}),
        // Signal 'EntriesChanged'
        QtMocHelpers::SignalData<void(const QList<QDBusObjectPath> &) const>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 11 },
        }}),
        // Signal 'FrontendWindowRectChanged'
        QtMocHelpers::SignalData<void(const QRect &) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 11 },
        }}),
        // Signal 'HideModeChanged'
        QtMocHelpers::SignalData<void(int) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'HideStateChanged'
        QtMocHelpers::SignalData<void(int) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'HideTimeoutChanged'
        QtMocHelpers::SignalData<void(uint) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'IconSizeChanged'
        QtMocHelpers::SignalData<void(uint) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'OpacityChanged'
        QtMocHelpers::SignalData<void(double) const>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 11 },
        }}),
        // Signal 'PositionChanged'
        QtMocHelpers::SignalData<void(int) const>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'ShowTimeoutChanged'
        QtMocHelpers::SignalData<void(uint) const>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'WindowMarginChanged'
        QtMocHelpers::SignalData<void(uint) const>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'WindowSizeChanged'
        QtMocHelpers::SignalData<void(uint) const>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'WindowSizeEfficientChanged'
        QtMocHelpers::SignalData<void(uint) const>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Signal 'WindowSizeFashionChanged'
        QtMocHelpers::SignalData<void(uint) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'ActivateWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(28, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'ActivateWindowQueued'
        QtMocHelpers::SlotData<void(uint)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'CancelPreviewWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(31, 2, QMC::AccessPublic, 0x80000000 | 29),
        // Slot 'CancelPreviewWindowQueued'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'CloseWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(33, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'CloseWindowQueued'
        QtMocHelpers::SlotData<void(uint)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'GetDockedAppsDesktopFiles'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(35, 2, QMC::AccessPublic, 0x80000000 | 36),
        // Slot 'GetEntryIDs'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(37, 2, QMC::AccessPublic, 0x80000000 | 36),
        // Slot 'GetPluginSettings'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(38, 2, QMC::AccessPublic, 0x80000000 | 39),
        // Slot 'IsDocked'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(40, 2, QMC::AccessPublic, 0x80000000 | 41, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'IsOnDock'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(42, 2, QMC::AccessPublic, 0x80000000 | 41, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'MakeWindowAbove'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(43, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MakeWindowAboveQueued'
        QtMocHelpers::SlotData<void(uint)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MaximizeWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(45, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MaximizeWindowQueued'
        QtMocHelpers::SlotData<void(uint)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MergePluginSettings'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(47, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'MergePluginSettingsQueued'
        QtMocHelpers::SlotData<void(const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'MinimizeWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(49, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MinimizeWindowQueued'
        QtMocHelpers::SlotData<void(uint)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MoveEntry'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int)>(51, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'MoveEntryQueued'
        QtMocHelpers::SlotData<void(int, int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'MoveWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(53, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MoveWindowQueued'
        QtMocHelpers::SlotData<void(uint)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'PreviewWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(55, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'PreviewWindowQueued'
        QtMocHelpers::SlotData<void(uint)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'QueryWindowIdentifyMethod'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(uint)>(57, 2, QMC::AccessPublic, 0x80000000 | 39, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'RemovePluginSettings'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QStringList &)>(58, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 5 }, { QMetaType::QStringList, 6 },
        }}),
        // Slot 'RemovePluginSettingsQueued'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QStringList, 6 },
        }}),
        // Slot 'RequestDock'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, int)>(60, 2, QMC::AccessPublic, 0x80000000 | 41, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'RequestUndock'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(61, 2, QMC::AccessPublic, 0x80000000 | 41, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'SetFrontendWindowRect'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int, int, int)>(62, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 }, { QMetaType::Int, 63 }, { QMetaType::Int, 64 },
        }}),
        // Slot 'SetFrontendWindowRectQueued'
        QtMocHelpers::SlotData<void(int, int, int, int)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 }, { QMetaType::Int, 63 }, { QMetaType::Int, 64 },
        }}),
        // Slot 'SetPluginSettings'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(66, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'SetPluginSettingsQueued'
        QtMocHelpers::SlotData<void(const QString &)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 69 }, { 0x80000000 | 70, 71 },
        }}),
        // Slot 'onPendingCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 73, 74 },
        }}),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 76 }, { 0x80000000 | 77, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DisplayMode'
        QtMocHelpers::PropertyData<int>(78, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'DockedApps'
        QtMocHelpers::PropertyData<QStringList>(79, QMetaType::QStringList, QMC::DefaultPropertyFlags, 6),
        // property 'Entries'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(80, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'FrontendWindowRect'
        QtMocHelpers::PropertyData<QRect>(81, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'HideMode'
        QtMocHelpers::PropertyData<int>(82, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'HideState'
        QtMocHelpers::PropertyData<int>(83, QMetaType::Int, QMC::DefaultPropertyFlags, 10),
        // property 'HideTimeout'
        QtMocHelpers::PropertyData<uint>(84, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'IconSize'
        QtMocHelpers::PropertyData<uint>(85, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'Opacity'
        QtMocHelpers::PropertyData<double>(86, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'Position'
        QtMocHelpers::PropertyData<int>(87, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'ShowTimeout'
        QtMocHelpers::PropertyData<uint>(88, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'WindowMargin'
        QtMocHelpers::PropertyData<uint>(89, QMetaType::UInt, QMC::DefaultPropertyFlags, 16),
        // property 'WindowSize'
        QtMocHelpers::PropertyData<uint>(90, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'WindowSizeEfficient'
        QtMocHelpers::PropertyData<uint>(91, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'WindowSizeFashion'
        QtMocHelpers::PropertyData<uint>(92, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<__Dock1, qt_meta_tag_ZN7__Dock1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject __Dock1::staticMetaObject = { {
    QMetaObject::SuperData::link<DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7__Dock1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7__Dock1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7__Dock1E_t>.metaTypes,
    nullptr
} };

void __Dock1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<__Dock1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->DockAppSettingsSynced(); break;
        case 1: _t->EntryAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->EntryRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->PluginSettingsSynced(); break;
        case 4: _t->ServiceRestarted(); break;
        case 5: _t->DisplayModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->DockedAppsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 7: _t->EntriesChanged((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1]))); break;
        case 8: _t->FrontendWindowRectChanged((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 9: _t->HideModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->HideStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->HideTimeoutChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 12: _t->IconSizeChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 13: _t->OpacityChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->PositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->ShowTimeoutChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 16: _t->WindowMarginChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 17: _t->WindowSizeChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 18: _t->WindowSizeEfficientChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 19: _t->WindowSizeFashionChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 20: { QDBusPendingReply<> _r = _t->ActivateWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->ActivateWindowQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 22: { QDBusPendingReply<> _r = _t->CancelPreviewWindow();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->CancelPreviewWindowQueued(); break;
        case 24: { QDBusPendingReply<> _r = _t->CloseWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->CloseWindowQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 26: { QDBusPendingReply<QStringList> _r = _t->GetDockedAppsDesktopFiles();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<QStringList> _r = _t->GetEntryIDs();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<QString> _r = _t->GetPluginSettings();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<bool> _r = _t->IsDocked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<bool> _r = _t->IsOnDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<> _r = _t->MakeWindowAbove((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->MakeWindowAboveQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 33: { QDBusPendingReply<> _r = _t->MaximizeWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->MaximizeWindowQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 35: { QDBusPendingReply<> _r = _t->MergePluginSettings((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->MergePluginSettingsQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: { QDBusPendingReply<> _r = _t->MinimizeWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->MinimizeWindowQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 39: { QDBusPendingReply<> _r = _t->MoveEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->MoveEntryQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 41: { QDBusPendingReply<> _r = _t->MoveWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->MoveWindowQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 43: { QDBusPendingReply<> _r = _t->PreviewWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->PreviewWindowQueued((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 45: { QDBusPendingReply<QString> _r = _t->QueryWindowIdentifyMethod((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 46: { QDBusPendingReply<> _r = _t->RemovePluginSettings((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->RemovePluginSettingsQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 48: { QDBusPendingReply<bool> _r = _t->RequestDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 49: { QDBusPendingReply<bool> _r = _t->RequestUndock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 50: { QDBusPendingReply<> _r = _t->SetFrontendWindowRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 51: _t->SetFrontendWindowRectQueued((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 52: { QDBusPendingReply<> _r = _t->SetPluginSettings((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->SetPluginSettingsQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 54: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        case 55: _t->onPendingCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 56: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)()>(_a, &__Dock1::DockAppSettingsSynced, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(const QDBusObjectPath & , int )>(_a, &__Dock1::EntryAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(const QString & )>(_a, &__Dock1::EntryRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)()>(_a, &__Dock1::PluginSettingsSynced, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)()>(_a, &__Dock1::ServiceRestarted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(int ) const>(_a, &__Dock1::DisplayModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(const QStringList & ) const>(_a, &__Dock1::DockedAppsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(const QList<QDBusObjectPath> & ) const>(_a, &__Dock1::EntriesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(const QRect & ) const>(_a, &__Dock1::FrontendWindowRectChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(int ) const>(_a, &__Dock1::HideModeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(int ) const>(_a, &__Dock1::HideStateChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(uint ) const>(_a, &__Dock1::HideTimeoutChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(uint ) const>(_a, &__Dock1::IconSizeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(double ) const>(_a, &__Dock1::OpacityChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(int ) const>(_a, &__Dock1::PositionChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(uint ) const>(_a, &__Dock1::ShowTimeoutChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(uint ) const>(_a, &__Dock1::WindowMarginChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(uint ) const>(_a, &__Dock1::WindowSizeChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(uint ) const>(_a, &__Dock1::WindowSizeEfficientChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (__Dock1::*)(uint ) const>(_a, &__Dock1::WindowSizeFashionChanged, 19))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->displayMode(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->dockedApps(); break;
        case 2: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->entries(); break;
        case 3: *reinterpret_cast<QRect*>(_v) = _t->frontendWindowRect(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->hideMode(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->hideState(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->hideTimeout(); break;
        case 7: *reinterpret_cast<uint*>(_v) = _t->iconSize(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->opacity(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->position(); break;
        case 10: *reinterpret_cast<uint*>(_v) = _t->showTimeout(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->windowMargin(); break;
        case 12: *reinterpret_cast<uint*>(_v) = _t->windowSize(); break;
        case 13: *reinterpret_cast<uint*>(_v) = _t->windowSizeEfficient(); break;
        case 14: *reinterpret_cast<uint*>(_v) = _t->windowSizeFashion(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDisplayMode(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setHideMode(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setHideTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 7: _t->setIconSize(*reinterpret_cast<uint*>(_v)); break;
        case 8: _t->setOpacity(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setPosition(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setShowTimeout(*reinterpret_cast<uint*>(_v)); break;
        case 12: _t->setWindowSize(*reinterpret_cast<uint*>(_v)); break;
        case 13: _t->setWindowSizeEfficient(*reinterpret_cast<uint*>(_v)); break;
        case 14: _t->setWindowSizeFashion(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *__Dock1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *__Dock1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7__Dock1E_t>.strings))
        return static_cast<void*>(this);
    return DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacast(_clname);
}

int __Dock1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 57)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 57;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 57)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 57;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void __Dock1::DockAppSettingsSynced()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void __Dock1::EntryAdded(const QDBusObjectPath & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void __Dock1::EntryRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void __Dock1::PluginSettingsSynced()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void __Dock1::ServiceRestarted()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void __Dock1::DisplayModeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void __Dock1::DockedAppsChanged(const QStringList & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void __Dock1::EntriesChanged(const QList<QDBusObjectPath> & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void __Dock1::FrontendWindowRectChanged(const QRect & _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void __Dock1::HideModeChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void __Dock1::HideStateChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void __Dock1::HideTimeoutChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void __Dock1::IconSizeChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void __Dock1::OpacityChanged(double _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void __Dock1::PositionChanged(int _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void __Dock1::ShowTimeoutChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void __Dock1::WindowMarginChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void __Dock1::WindowSizeChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void __Dock1::WindowSizeEfficientChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void __Dock1::WindowSizeFashionChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< __Dock1 *>(this), &staticMetaObject, 19, nullptr, _t1);
}
QT_WARNING_POP
