/****************************************************************************
** Meta object code from reading C++ file 'multipagesortfilterproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../multipagesortfilterproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multipagesortfilterproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29MultipageSortFilterProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MultipageSortFilterProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN29MultipageSortFilterProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MultipageSortFilterProxyModel",
        "QML.Element",
        "onFolderIdChanged",
        "",
        "onPageIdChanged",
        "sourceModelChanged",
        "onFilterOnlyModeChanged",
        "sourceModel",
        "QAbstractItemModel*",
        "folderId",
        "pageId",
        "filterOnlyMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'onFolderIdChanged'
        QtMocHelpers::SignalData<void(int)>(2, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'onPageIdChanged'
        QtMocHelpers::SignalData<void(int)>(4, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'sourceModelChanged'
        QtMocHelpers::SignalData<void(QObject *)>(5, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 },
        }}),
        // Signal 'onFilterOnlyModeChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sourceModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 2),
        // property 'folderId'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'pageId'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'filterOnlyMode'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
    });
    return QtMocHelpers::metaObjectData<MultipageSortFilterProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MultipageSortFilterProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29MultipageSortFilterProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29MultipageSortFilterProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29MultipageSortFilterProxyModelE_t>.metaTypes,
    nullptr
} };

void MultipageSortFilterProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MultipageSortFilterProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onFolderIdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->onPageIdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->sourceModelChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 3: _t->onFilterOnlyModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MultipageSortFilterProxyModel::*)(int )>(_a, &MultipageSortFilterProxyModel::onFolderIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultipageSortFilterProxyModel::*)(int )>(_a, &MultipageSortFilterProxyModel::onPageIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultipageSortFilterProxyModel::*)(QObject * )>(_a, &MultipageSortFilterProxyModel::sourceModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultipageSortFilterProxyModel::*)(bool )>(_a, &MultipageSortFilterProxyModel::onFilterOnlyModeChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->sourceModel(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->m_folderId; break;
        case 2: *reinterpret_cast<int*>(_v) = _t->m_pageId; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_filterOnlyMode; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_folderId, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->onFolderIdChanged(_t->m_folderId);
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_pageId, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->onPageIdChanged(_t->m_pageId);
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_filterOnlyMode, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->onFilterOnlyModeChanged(_t->m_filterOnlyMode);
            break;
        default: break;
        }
    }
}

const QMetaObject *MultipageSortFilterProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MultipageSortFilterProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29MultipageSortFilterProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int MultipageSortFilterProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void MultipageSortFilterProxyModel::onFolderIdChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MultipageSortFilterProxyModel::onPageIdChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MultipageSortFilterProxyModel::sourceModelChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MultipageSortFilterProxyModel::onFilterOnlyModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
