/****************************************************************************
** Meta object code from reading C++ file 'categorizedsortproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../categorizedsortproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'categorizedsortproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25CategorizedSortProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto CategorizedSortProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN25CategorizedSortProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CategorizedSortProxyModel",
        "QML.Element",
        "QML.Singleton",
        "true",
        "categoryTypeChanged",
        "",
        "sectionRoleNameChanged",
        "alphabetarySections",
        "DDECategorySections",
        "QList<int>",
        "categoryType",
        "CategoryType",
        "sortRoleName",
        "sectionRoleName",
        "Alphabetary",
        "DDECategory",
        "FreeCategory"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'categoryTypeChanged'
        QtMocHelpers::SignalData<void()>(4, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sectionRoleNameChanged'
        QtMocHelpers::SignalData<void()>(6, 5, QMC::AccessPublic, QMetaType::Void),
        // Method 'alphabetarySections'
        QtMocHelpers::MethodData<QList<QString>() const>(7, 5, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'DDECategorySections'
        QtMocHelpers::MethodData<QList<int>() const>(8, 5, QMC::AccessPublic, 0x80000000 | 9),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'categoryType'
        QtMocHelpers::PropertyData<enum CategoryType>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'sortRoleName'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'sectionRoleName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CategoryType'
        QtMocHelpers::EnumData<enum CategoryType>(11, 11, QMC::EnumFlags{}).add({
            {   14, CategoryType::Alphabetary },
            {   15, CategoryType::DDECategory },
            {   16, CategoryType::FreeCategory },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
    });
    return QtMocHelpers::metaObjectData<CategorizedSortProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CategorizedSortProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25CategorizedSortProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25CategorizedSortProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25CategorizedSortProxyModelE_t>.metaTypes,
    nullptr
} };

void CategorizedSortProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CategorizedSortProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->categoryTypeChanged(); break;
        case 1: _t->sectionRoleNameChanged(); break;
        case 2: { QList<QString> _r = _t->alphabetarySections();
            if (_a[0]) *reinterpret_cast<QList<QString>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QList<int> _r = _t->DDECategorySections();
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CategorizedSortProxyModel::*)()>(_a, &CategorizedSortProxyModel::categoryTypeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CategorizedSortProxyModel::*)()>(_a, &CategorizedSortProxyModel::sectionRoleNameChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum CategoryType*>(_v) = _t->categoryType(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->sortRoleName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->sectionRoleName(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCategoryType(*reinterpret_cast<enum CategoryType*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *CategorizedSortProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CategorizedSortProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25CategorizedSortProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int CategorizedSortProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void CategorizedSortProxyModel::categoryTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CategorizedSortProxyModel::sectionRoleNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
